use structopt::StructOpt;

#[derive(Debug, StructOpt)]
#[structopt(
    name = "Open Meteo CLI",
    about = "CLI to extract meteorology data from Open Meteo"
)]
pub enum Arguments {
    #[structopt(about = "Gets the current weather for a coordinate")]
    CurrentWeather {
        #[structopt(short = "l", long, help = "Latitude as a decimal number")]
        latitude: f32,
        #[structopt(short = "L", long, help = "Altitude as a decimal number")]
        longitude: f32,

        #[structopt(short = "a", long, help = "Prints all the parameters")]
        all: bool,
        #[structopt(short = "d", long, help = "Prints if its day or night")]
        is_day: bool,
        #[structopt(short = "t", long, help = "Prints decimal temperature")]
        temperature: bool,
        #[structopt(short = "w", long, help = "Prints decimal wind speed")]
        windspeed: bool,
        #[structopt(short = "W", long, help = "Prints wind direction angle")]
        winddirection: bool,
        #[structopt(
            short = "c",
            long,
            help = "Cleans the output, and only shows the values separates by commas. 
- ORDER: is_day, temperature, windspeed, winddirection
- EXAMPLE: 1,22.4,12.5,170.0"
        )]
        clean: bool,
    },
}
